#
# spec file for package python-humanfriendly
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
# Dependency loop with colorlogs
%bcond_with     test
Name:           python-humanfriendly
Version:        4.4.1
Release:        lp150.2.1
Summary:        Human friendly input/output for text interfaces using Python
License:        MIT
Group:          Development/Languages/Python
Url:            https://github.com/xolox/humanfriendly
Source:         https://files.pythonhosted.org/packages/source/h/humanfriendly/humanfriendly-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  python-monotonic
%if %{with test}
BuildRequires:  %{python_module coloredlogs >= 2}
%endif
%ifpython2
Requires:       python-monotonic
%endif
BuildArch:      noarch
Requires(post): update-alternatives
Requires(postun): update-alternatives

%python_subpackages

%description
The functions and classes in the humanfriendly package can be used to make
text interfaces more user friendly.

 Some example features:
  * Parsing and formatting numbers, file sizes, pathnames and timespans in
    simple, human friendly formats.
  * Easy to use timers for long running operations, with human friendly
    formatting of the resulting timespans.
  * Prompting the user to select a choice from a list of options by typing
    the option’s number or a unique substring of the option.
  * Terminal interaction including text styling (ANSI escape sequences), user
    friendly rendering of usage messages and querying the terminal for its size.

%prep
%setup -q -n humanfriendly-%{version}

%build
%python_build

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/humanfriendly
%{python_expand chmod a+x %{buildroot}%{$python_sitelib}/humanfriendly/tests.py
sed -i "s|#!/usr/bin/env python|#!%__$python|" %{buildroot}%{$python_sitelib}/humanfriendly/tests.py
$python -m compileall -d %{$python_sitelib} %{buildroot}%{$python_sitelib}/humanfriendly/
$python -O -m compileall -d %{$python_sitelib} %{buildroot}%{$python_sitelib}/humanfriendly/
%fdupes %{buildroot}%{$python_sitelib}
}

%post
%python_install_alternative humanfriendly

%postun
%python_uninstall_alternative humanfriendly

%if %{with test}
%check
%python_exec setup.py test
popd
%endif

%files %{python_files}
%defattr(-,root,root,-)
%doc LICENSE.txt README.rst
%python_alternative %{_bindir}/humanfriendly
%{python_sitelib}/humanfriendly
%{python_sitelib}/humanfriendly-%{version}-py*.egg-info

%changelog
* Wed Sep  6 2017 toddrme2178@gmail.com
- Implement single-spec version.
- Update to version 4.4.1
  * No changelog
* Mon Oct 10 2016 mardnh@gmx.de
- Update to version 2.1
  * Release 2.1: Support for sanitizing terminal output
  * Support for sanitizing terminal output
  * Merge #12: Update README.rst for new unit behaviour
  * Update README.rst for new unit behaviour
  * Release 2.0: Proper support for IEEE 1541 definitions of units? (fixes #4, merges #8 and #9)
  * Proper support for IEEE 1541 definitions of units?
  * Merge #9: Add note about IEEE 1541 definitions of units
  * Merge #8: Allow correct behavior of 'parse_size' and 'format_size'
  * Stop clearing coverage data on Travis CI :-)
  * Release 1.44.9 (fixes #10 and #11)
  * Restore Python 2.6 compatibility (#10 and #11)
  * Resolve timespan formatting issues (#10 and #11)
  * Reproduce timespan formatting issues reported in #10 and #11
  * Refactor makefile, switch to py.test, wheel support, etc.
  * Release 1.44.8 (fixes #7)
  * Don't test tags on Travis CI
  * Fix issue #7
  * Reproduce issue #7 in test suite
  * Minor improvements to setup script
  * Add note about IEEE 1541 definitions of units
  * Added unit tests
  * Implemented correct handling of prefixes based on IEEE 1540
- Fix source url
- Minor specfile cleanup
* Wed Jun  1 2016 okurz@suse.com
- Update to official release 1.44.7
  Minor improvements to usage message reformatting
  Remove undocumented .strip() from join_lines()
  Why I noticed this: It has the potential to eat significant white
  space in usage messages that are marked up in reStructuredText syntax.
  Why I decided to change it: The behavior isn't documented and on
  second thought I wouldn't expect a function called join_lines()
  to strip any and all leading/trailing white space.
  Improve usage message parsing algorithm (also add a proper test)
  Refer to test_parse_usage_tricky() for an example of a usage message that
  is now parsed correctly but would previously confuse the dumb "parsing"
  algorithm in parse_usage().
  Make usage message parsing a bit more strict
  Admittedly this needs a lot more love to make it more robust but
  I lack the time to implement this at the moment. Some day soon! :-)
  Unbreak conditional importlib dependency*
  * https://travis-ci.org/xolox/python-humanfriendly/builds/110585766
  Kind of strange that everything worked fine locally. Then again,
  I've never used wheel compatible conditional dependencies before
  so of course my first attempt was bound to fail in same way :-s.
  Make conditional importlib dependency compatible with wheels*
  While running tox tests of another project of mine that uses the
  humanfriendly package I noticed a traceback when importing the
  humanfriendly package (because importlib was missing). After some
  digging I found that tox uses pip to install packages and pip converts
  source distributions to wheel distributions before/during installation,
  thereby dropping the conditional importlib dependency.
  Fix non-fatal log format error in prompt_for_choice()
  Add humanfriendly.sphinx module
* Mon Jan 25 2016 okurz@suse.de
- initial package
